# Hotpot

<div style="text-align: center">
<img src="https://github.com/RutaTang/Hotpot/blob/master/artworks/hotpot.png?raw=true" style="width: 150px;height: 150px;">
</div>

**A tiny and easy python web framework just for your fun! :)**

*By the way, if you never know the hotpot, you may miss one of the most delicious,fragrant and tasty food in the world ~
\_~*


